﻿Feature: Publish test results

Background: 
	Given there is an Azure DevOps project with an empty test suite 'MySuite'
	And the synchronizer is configured to add test cases to test suite 'MySuite'

Rule: Should be able to publish test results

@tc:253
Scenario: Results of scenarios and scenario outlines are captured
	Given there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case-1]
		Scenario: Passing scenario
			When the scenario pass

		@tc:[id-of-test-case-2]
		Scenario: Failing scenario
			When the scenario fail

		@tc:[id-of-test-case-3]
		Scenario Outline: Mixed results
			When the scenario <result>
		Examples:
			| result |
			| pass   |
			| fail   |
		"""
	And there is a test result file with
		| name              | className                      | outcome |
		| PassingScenario   | MyProject.SampleFeatureFeature | Passed  |
		| FailingScenario   | MyProject.SampleFeatureFeature | Failed  |
		| MixedResults_Pass | MyProject.SampleFeatureFeature | Passed  |
		| MixedResults_Fail | MyProject.SampleFeatureFeature | Failed  |
	When the test result is published to configuration "Windows 8"
	Then the command should succeed
	And the there should be a test run registered with test results
		| test case ID        | outcome |
		| [id-of-test-case-1] | Passed  |
		| [id-of-test-case-2] | Failed  |
		| [id-of-test-case-3] | Failed  |

@tc:254
Scenario: The test result file is attached to the test run
	Given there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case]
		Scenario: Sample scenario
			When I do something
		"""
	And there is a test result file "TestResult.trx" with
		| name           | className                      | methodName     | adapterTypeName             | test result name | outcome |
		| SampleScenario | MyProject.SampleFeatureFeature | SampleScenario | executor://mstestadapter/v2 | SampleScenario   | Passed  |
	When the test result is published to configuration "Windows 8"
	Then the command should succeed
	And the there should be a test run registered with attachments
		| file name      | attachment type   | comment  |
		| TestResult.trx | TmiTestRunSummary | TRX File |

Rule: Additional details can be specified for the created Test Run

@tc:255
Scenario: Test run settings are specified
	Given there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case]
		Scenario: Sample scenario
			When I do something
		"""
	And there is a test result file with
		| name           | className                      | outcome |
		| SampleScenario | MyProject.SampleFeatureFeature | Passed  |
	And the publishing is configured with
		| setting    | value      |
		| runName    | My run     |
		| runComment | My comment |
	When the test result is published to configuration "Windows 8"
	Then the command should succeed
	And the there should be a test run registered with 
		| setting        | value      |
		| Run name       | My run     |
		| Run comment    | My comment |

@tc:256
Scenario: Test result comment is provided
	Given there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case-1]
		Scenario: Sample scenario
			When I do something

		@tc:[id-of-test-case-2]
		Scenario Outline: Mixed results
			When the scenario <result>
		Examples:
			| result |
			| pass   |
			| fail   |
		"""
	And there is a test result file with
		| name              | className                      | outcome |
		| SampleScenario    | MyProject.SampleFeatureFeature | Passed  |
		| MixedResults_Pass | MyProject.SampleFeatureFeature | Passed  |
		| MixedResults_Fail | MyProject.SampleFeatureFeature | Failed  |
	And the publishing is configured with
		| setting           | value      |
		| testResultComment | My comment |
	When the test result is published
	Then the command should succeed
	And the there should be a test run registered with test results
		| test case ID        | comment                                                                |
		| [id-of-test-case-1] | My comment                                                             |
		| [id-of-test-case-2] | My comment;<br>MixedResults_Pass: Passed;<br>MixedResults_Fail: Failed |

Rule: Test Run is created as Automated if scenarios are sycnhronized as automated Test Cases

Scenario Outline: Test Run automation status is set based on whether scenarios are synchronized to automated test cases
	Given the synchronizer is configured to <synchronize to automated> automation
	And there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case]
		Scenario: Sample scenario
			When I do something
		"""
	And there is a test result file with
		| name           | className                      | outcome |
		| SampleScenario | MyProject.SampleFeatureFeature | Passed  |
	When the test result is published
	Then the command should succeed
	And the there should be a test run registered with 
		| setting      | value                        |
		| Is Automated | <expected automation status> |
Examples: 
	| description                                                      | synchronize to automated | expected automation status |
	| scenarios are synchronized as automated Test Cases               | enable                   | true                       |
	| scenarios are synchronized as not automated Test Cases (default) | skip                     | false                      |

@notsupported-ado2019 @notsupported-tfs2018
Scenario Outline: Test Run automation status can be overridden (automation mismatch)
	This case might lead to automation mismatch error in older Azure DevOps servers
	Given the synchronizer is configured to <synchronize to automated> automation
	And there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case]
		Scenario: Sample scenario
			When I do something
		"""
	And there is a test result file with
		| name           | className                      | outcome |
		| SampleScenario | MyProject.SampleFeatureFeature | Passed  |
	And the publishing is configured with
		| setting  | value      |
		| Run Type | <run type> |
	When the test result is published
	Then the command should succeed
	And the there should be a test run registered with 
		| setting      | value                        |
		| Is Automated | <expected automation status> |
Examples: 
	| description                                   | synchronize to automated | run type  | expected automation status |
	| Publish automated Test Cases as Manual        | enable                   | Manual    | false                      |
	| Publish non-automated Test Cases as Automated | skip                     | Automated | true                       |

Rule: The test run can be connected with an Azure DevOps build

@tc:257
Scenario: Build details are specified
	Given there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case]
		Scenario: Sample scenario
			When I do something
		"""
	And there is a test result file with
		| name           | className                      | outcome |
		| SampleScenario | MyProject.SampleFeatureFeature | Passed  |
	And the publishing is configured with
		| setting       | value                   |
		| buildNumber   | [existing-build-number] |
		| buildPlatform | x86                     |
		| buildFlavor   | Debug                   |
	When the test result is published to configuration "Windows 8"
	Then the command should succeed
	And the there should be a test run registered with 
		| setting        | value               |
		| Build Id       | [existing-build-id] |
		| Build platform | x86                 |
		| Build flavor   | Debug               |

Rule: Inconclusive test result can be mapped

@tc:258
Scenario: Inconclusive is treated as skipped (NotExecuted)
	Given there is a feature file that was already synchronized before
		"""
		Feature: Sample feature

		@tc:[id-of-test-case]
		Scenario Outline: Mixed results
			When the scenario <result>
		Examples:
			| result       |
			| pass         |
			| inconclusive |
		"""
	And there is a test result file with
		| name                      | className                      | outcome      |
		| MixedResults_Pass         | MyProject.SampleFeatureFeature | Passed       |
		| MixedResults_Inconclusive | MyProject.SampleFeatureFeature | Inconclusive |
	And the publishing is configured with
		| setting             | value       |
		| treatInconclusiveAs | NotExecuted |
	When the test result is published to configuration "Windows 8"
	Then the command should succeed
	And the there should be a test run registered with test results
		| test case ID      | outcome |
		| [id-of-test-case] | Passed  |

